"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _path = _interopRequireDefault(require("path"));

var _fsExtra = _interopRequireDefault(require("fs-extra"));

var _utils = require("../../utils");

var _isFunction = _interopRequireDefault(require("lodash/isFunction"));

var _isString = _interopRequireDefault(require("lodash/isString"));

var _filter = _interopRequireDefault(require("lodash/filter"));

var _map = _interopRequireDefault(require("lodash/map"));

var _store = _interopRequireDefault(require("../../store"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const RUN = Symbol('run');

function createRegexp(match) {
  if ((0, _isFunction.default)(match)) {
    return match;
  }

  if (match) {
    return pathToRegexp(match);
  }
}

function checkMatch(rule, ctx) {
  if ((0, _isFunction.default)(rule)) {
    return rule(ctx);
  }

  return rule.test(ctx.path);
}

function checkMid(name) {
  try {
    return require.resolve(name, {
      paths: jinghuanjs.paths
    });
  } catch (e) {
    return false;
  }
}

function requireMid(item) {
  let socket = "";

  let appMid = require.resolve(_path.default.join(jinghuanjs.APP_PATH, 'runtime', 'socketio', item.handle));

  if (_fsExtra.default.pathExistsSync(appMid)) {
    let cache = require.cache[appMid];

    if (!cache) {
      let handle = require(appMid);

      if (handle) {
        item[RUN] = handle(item.options, jinghuanjs.socketio);
      }
    }
  }

  if (!item[RUN]) {
    console.error(`socketio ${item.handle} Load Fail`);
  }
}

function parse(middleware = []) {
  return (0, _map.default)(middleware, item => {
    requireMid(item);
    return (ctx, next) => {
      if (!(0, _isFunction.default)(item[RUN])) {
        item[RUN] = item.handle(item.options, jinghuanjs.app);
      }

      return item[RUN](ctx, next);
    };
  });
}

function load() {
  let middleware = jinghuanjs.config('socketio') || [];
  let legal = (0, _filter.default)(middleware, ({
    handle
  }) => (0, _isString.default)(handle));
  let strings = (0, _map.default)(legal, ({
    handle
  }) => handle);
  _store.default.iomid = strings;
  return parse(legal);
}

var _default = load;
exports.default = _default;
module.exports = exports.default;