"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _isString = _interopRequireDefault(require("lodash/isString"));

var _isObject = _interopRequireDefault(require("lodash/isObject"));

var _get = _interopRequireDefault(require("lodash/get"));

var _fs = _interopRequireDefault(require("fs"));

var _path = _interopRequireDefault(require("path"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function requireResolve(name) {
  try {
    return require.resolve(name, {
      paths: jinghuanjs.paths
    });
  } catch (e) {
    return null;
  }
}

function find(name, ctx, def = null) {
  if ((0, _isString.default)(ctx)) {
    if ((0, _isObject.default)(jinghuan[name])) {
      return (0, _get.default)(jinghuan[name], ctx, def);
    }
  } else if ((0, _isObject.default)(ctx)) {
    if ((0, _isObject.default)(jinghuan[name])) {
      let {
        module,
        controller,
        action
      } = ctx;
      let ret = null;

      if (!ret) {
        ret = (0, _get.default)(jinghuan[name], `${module}.${controller}/${action}`);
      }

      if (!ret) {
        ret = (0, _get.default)(jinghuan[name], `${module}.${controller}.${action}`);
      }

      if (!ret) {
        ret = (0, _get.default)(jinghuan[name], `${module}.${controller}`);
      }

      return ret || def;
    }
  }

  return def;
}

function extend(target, source) {
  const properties = Object.getOwnPropertyNames(source).concat(Object.getOwnPropertySymbols(source));
  const length = properties.length;

  for (let i = 0; i < length; i++) {
    const property = properties[i];
    const descriptor = Object.getOwnPropertyDescriptor(source, property);

    if (descriptor.get && descriptor.set) {
      Object.defineProperty(target, property, {
        configurable: true,
        get: descriptor.get,
        set: descriptor.set
      });
    } else if (descriptor.get) {
      Object.defineProperty(target, property, {
        configurable: true,
        get: descriptor.get
      });
    } else if (descriptor.set) {
      Object.defineProperty(target, property, {
        configurable: true,
        set: descriptor.set
      });
    } else if (descriptor.hasOwnProperty('value')) {
      target[property] = descriptor.value;
    }
  }

  return target;
}

;

function esModule(obj) {
  return obj && obj.__esModule ? obj.default : obj;
}

function define(name, val, target = {}) {
  Object.defineProperty(target, name, {
    configurable: false,
    enumerable: true,
    writable: false,
    value: val
  });
}

function isExist(dir) {
  dir = _path.default.normalize(dir);

  try {
    _fs.default.accessSync(dir, _fs.default.R_OK);

    return true;
  } catch (e) {
    return false;
  }
}

function isFile(filePath) {
  if (!isExist(filePath)) {
    return false;
  }

  try {
    const stat = _fs.default.statSync(filePath);

    return stat.isFile();
  } catch (e) {
    return false;
  }
}

function isDirectory(filePath) {
  if (!isExist(filePath)) {
    return false;
  }

  try {
    const stat = _fs.default.statSync(filePath);

    return stat.isDirectory();
  } catch (e) {
    return false;
  }
}

function getDirFiles(dir, prefix = '') {
  dir = _path.default.normalize(dir);

  if (!_fs.default.existsSync(dir)) {
    return [];
  }

  const files = _fs.default.readdirSync(dir);

  let result = [];
  files.forEach(item => {
    const currentDir = _path.default.join(dir, item);

    const stat = _fs.default.statSync(currentDir);

    if (stat.isFile()) {
      result.push(_path.default.join(prefix, item));
    } else if (stat.isDirectory()) {
      const cFiles = getDirFiles(currentDir, _path.default.join(prefix, item));
      result = result.concat(cFiles);
    }
  });
  return result;
}

;

function loadFiles(dir, ext = [], load = false) {
  if ((0, _isString.default)(ext)) {
    ext = [ext];
  }

  const ragexp = new RegExp('\\.(' + ext.join('|') + ')$');
  const cache = {};
  getDirFiles(dir).filter(file => {
    return ragexp.test(file);
  }).forEach(file => {
    const name = file.replace(/\\/g, '/').replace(ragexp, '');

    if (load) {
      cache[name] = require(_path.default.join(dir, file));
    } else {
      cache[name] = _path.default.join(dir, file);
    }
  });
  return cache;
}

;
var _default = {
  requireResolve,
  find,
  extend,
  esModule,
  define,
  isFile,
  isExist,
  isDirectory,
  getDirFiles,
  loadFiles
};
exports.default = _default;
module.exports = exports.default;